OC.L10N.register(
    "notes",
    {
    "Notes" : "ノート",
    "The last viewed note cannot be accessed. " : "最後に閲覧したノートにはアクセスできません。",
    "The notes folder is not accessible: %s" : "ノートフォルダーはアクセスできません：%s",
    "Encryption Error" : "暗号化エラー",
    "Error" : "エラー",
    "New note" : "新しいノート",
    "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
    "Settings" : "設定",
    "Folder to store your notes" : "ノートを保存するフォルダー",
    "path to notes" : "ノートへのパス",
    "File extension for new notes" : "新しいノートのファイル拡張子",
    "All notes" : "すべてのノート",
    "Categories" : "カテゴリ",
    "Today" : "今日",
    "This week" : "今週",
    "Last week" : "先週",
    "This month" : "今月",
    "Last month" : "先月",
    "Delete note" : "ノートを削除",
    "Category" : "カテゴリ",
    "Uncategorized" : "未分類",
    "Saving failed!" : "保存に失敗しました",
    "_%n word_::_%n words_" : ["%n 単語"],
    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？"
},
"nplurals=1; plural=0;");
